@@ -1,8 +1,10 @@
 #include "gt-channel.h"
 #include "gt-app.h"
-#include "utils.h"
 #include <json-glib/json-glib.h>
 
+#define TAG "GtChannel"
+#include "utils.h"
+
 #define N_JSON_PROPS 2
 
 typedef struct
@@ -17,12 +19,11 @@ typedef struct
     gchar* video_banner_url;
 
     GdkPixbuf* preview;
-    GdkPixbuf* video_banner;
 
     gint64 viewers;
     GDateTime* stream_started_time;
 
-    gboolean favourited;
+    gboolean followed;
     gboolean online;
     gboolean auto_update;
     gboolean updating;
@@ -34,6 +35,7 @@ typedef struct
     guint update_id;
 
     GCancellable* cancel;
+    GCancellable* cache_cancel;
 } GtChannelPrivate;
 
 static GThreadPool* update_pool;
@@ -59,7 +61,7 @@ enum
     PROP_PREVIEW,
     PROP_VIEWERS,
     PROP_STREAM_STARTED_TIME,
-    PROP_FAVOURITED,
+    PROP_FOLLOWED,
     PROP_ONLINE,
     PROP_AUTO_UPDATE,
     PROP_UPDATING,
@@ -78,58 +80,53 @@ gt_channel_new(const gchar* name, gint64 id)
 }
 
 static inline void
-set_banner(GtChannel* self, GdkPixbuf* banner, gboolean save, gboolean set_preview)
+set_banner(GtChannel* self, GdkPixbuf* banner, gboolean save)
 {
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    g_clear_object(&priv->video_banner);
-    priv->video_banner = banner;
+    priv->preview = banner;
 
     if (save)
-        gdk_pixbuf_save(priv->video_banner, priv->cache_filename,
+        gdk_pixbuf_save(priv->preview, priv->cache_filename,
                         "jpeg", NULL, NULL);
 
-    utils_pixbuf_scale_simple(&priv->video_banner,
+    utils_pixbuf_scale_simple(&priv->preview,
                               320, 180,
                               GDK_INTERP_BILINEAR);
 
-    if (set_preview)
-    {
-        priv->preview = priv->video_banner;
-        g_object_notify_by_pspec(G_OBJECT(self), props[PROP_PREVIEW]);
-    }
+    g_object_notify_by_pspec(G_OBJECT(self), props[PROP_PREVIEW]);
 }
 
 static void
-channel_favourited_cb(GtFavouritesManager* mgr,
+channel_followed_cb(GtFollowsManager* mgr,
                       GtChannel* chan,
                       gpointer udata)
 {
     GtChannel* self = GT_CHANNEL(udata);
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    if (!gt_channel_compare(self, chan) && !priv->favourited)
+    if (!gt_channel_compare(self, chan) && !priv->followed)
     {
-        GQuark detail = g_quark_from_static_string("favourited");
+        GQuark detail = g_quark_from_static_string("followed");
         g_signal_handlers_block_matched(self, G_SIGNAL_MATCH_DATA | G_SIGNAL_MATCH_DETAIL, 0, detail, NULL, NULL, main_app->fav_mgr);
-        g_object_set(self, "favourited", TRUE, NULL);
+        g_object_set(self, "followed", TRUE, NULL);
         g_signal_handlers_unblock_matched(self, G_SIGNAL_MATCH_DATA | G_SIGNAL_MATCH_DETAIL, 0, detail, NULL, NULL, main_app->fav_mgr);
     }
 }
 
 static void
-channel_unfavourited_cb(GtFavouritesManager* mgr,
+channel_unfollowed_cb(GtFollowsManager* mgr,
                         GtChannel* chan,
                         gpointer udata)
 {
     GtChannel* self = GT_CHANNEL(udata);
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    if (!gt_channel_compare(self, chan) && priv->favourited)
+    if (!gt_channel_compare(self, chan) && priv->followed)
     {
-        GQuark detail = g_quark_from_static_string("favourited");
+        GQuark detail = g_quark_from_static_string("followed");
         g_signal_handlers_block_matched(self, G_SIGNAL_MATCH_DATA | G_SIGNAL_MATCH_DETAIL, 0, detail, NULL, NULL, main_app->fav_mgr);
-        g_object_set(self, "favourited", FALSE, NULL);
+        g_object_set(self, "followed", FALSE, NULL);
         g_signal_handlers_unblock_matched(self, G_SIGNAL_MATCH_DATA | G_SIGNAL_MATCH_DETAIL, 0, detail, NULL, NULL, main_app->fav_mgr);
     }
 }
@@ -188,19 +185,27 @@ static void
 cache_update_cb(gpointer data,
                 gpointer udata)
 {
-    if(!GT_IS_CHANNEL(data)) // We were probably unrefed during wait time.
-        return;
+    GCancellable* cancel = G_CANCELLABLE(data);
 
-    GtChannel* self = GT_CHANNEL(data);
+    if (g_cancellable_is_cancelled(cancel))
+    {
+        g_debug("{GtChannel} Unrefed while waiting to update cache");
+        g_clear_object(&cancel);
+        return;
+    }
+
+    GtChannel* self = GT_CHANNEL(g_object_get_data(G_OBJECT(cancel), "chan"));
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
     GdkPixbuf* pic = gt_twitch_download_picture(main_app->twitch, priv->video_banner_url,
                                                 priv->cache_timestamp);
     if (pic)
     {
-        set_banner(self, pic, TRUE, FALSE);
+        set_banner(self, pic, TRUE);
         g_info("{GtChannel} Updated cache entry for channel '%s'", priv->name);
     }
+
+    g_clear_object(&cancel);
 }
 
 static void
@@ -252,7 +257,7 @@ download_banner_cb(GObject* source,
     GtChannel* self = GT_CHANNEL(udata);
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    set_banner(self, pic, TRUE, TRUE);
+    set_banner(self, pic, TRUE);
 
     priv->updating = FALSE;
     g_object_notify_by_pspec(G_OBJECT(self), props[PROP_UPDATING]);
@@ -281,9 +286,13 @@ download_banner(GtChannel* self)
                                              download_banner_cb, self);
         else
         {
-            g_thread_pool_push(cache_update_pool, self, NULL);
+            g_clear_object(&priv->cache_cancel);
+            priv->cache_cancel = g_cancellable_new();
+            g_object_ref(G_OBJECT(priv->cache_cancel));
+            g_object_set_data(G_OBJECT(priv->cache_cancel), "chan", self);
+            g_thread_pool_push(cache_update_pool, priv->cache_cancel, NULL);
 
-            set_banner(self, banner, FALSE, TRUE);
+            set_banner(self, banner, FALSE);
 
             priv->updating = FALSE;
             g_object_notify_by_pspec(G_OBJECT(self), props[PROP_UPDATING]);
@@ -291,8 +300,8 @@ download_banner(GtChannel* self)
     }
     else
     {
-        set_banner(self, gdk_pixbuf_new_from_resource("/com/gnome-twitch/icons/offline.png", NULL),
-                   FALSE, TRUE);
+        set_banner(self, gdk_pixbuf_new_from_resource("/com/vinszent/GnomeTwitch/icons/offline.png", NULL),
+                   FALSE);
 
         priv->updating = FALSE;
         g_object_notify_by_pspec(G_OBJECT(self), props[PROP_UPDATING]);
@@ -304,28 +313,15 @@ update_preview(GtChannel* self)
 {
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    g_cancellable_reset(priv->cancel);
+    g_cancellable_cancel(priv->cancel);
+    g_clear_object(&priv->cancel);
+    priv->cancel = g_cancellable_new();
 
     if (priv->online)
-    {
         gt_twitch_download_picture_async(main_app->twitch, priv->preview_url, priv->preview_timestamp,
                                          priv->cancel, download_preview_cb, self);
-    }
     else
-    {
-        g_clear_object(&priv->preview);
-
-        if (priv->video_banner)
-        {
-            priv->preview = g_object_ref(priv->video_banner);
-            g_object_notify_by_pspec(G_OBJECT(self), props[PROP_PREVIEW]);
-
-            priv->updating = FALSE;
-            g_object_notify_by_pspec(G_OBJECT(self), props[PROP_UPDATING]);
-        }
-        else
-            download_banner(self);
-    }
+        download_banner(self);
 }
 
 static void
@@ -335,24 +331,28 @@ finalize(GObject* object)
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
     g_cancellable_cancel(priv->cancel);
+    g_cancellable_cancel(priv->cache_cancel);
 
     g_free(priv->name);
     g_free(priv->display_name);
     g_free(priv->game);
     g_free(priv->status);
     g_free(priv->cache_filename);
+    g_free(priv->preview_url);
+    g_free(priv->video_banner_url);
 
     if (priv->stream_started_time)
         g_date_time_unref(priv->stream_started_time);
 
     g_clear_object(&priv->preview);
-    g_clear_object(&priv->video_banner);
+    g_clear_object(&priv->cancel);
+    g_clear_object(&priv->cache_cancel);
 
     if (priv->update_id > 0)
         g_source_remove(priv->update_id);
 
-    g_signal_handlers_disconnect_by_func(main_app->fav_mgr, channel_favourited_cb, self);
-    g_signal_handlers_disconnect_by_func(main_app->fav_mgr, channel_unfavourited_cb, self);
+    g_signal_handlers_disconnect_by_func(main_app->fav_mgr, channel_followed_cb, self);
+    g_signal_handlers_disconnect_by_func(main_app->fav_mgr, channel_unfollowed_cb, self);
 
     G_OBJECT_CLASS(gt_channel_parent_class)->finalize(object);
 }
@@ -398,8 +398,8 @@ get_property (GObject*    obj,
         case PROP_STREAM_STARTED_TIME:
             g_value_set_pointer(val, priv->stream_started_time);
             break;
-        case PROP_FAVOURITED:
-            g_value_set_boolean(val, priv->favourited);
+        case PROP_FOLLOWED:
+            g_value_set_boolean(val, priv->followed);
             break;
         case PROP_ONLINE:
             g_value_set_boolean(val, priv->online);
@@ -463,8 +463,8 @@ set_property(GObject*      obj,
             if (priv->stream_started_time)
                 g_date_time_ref(priv->stream_started_time);
             break;
-        case PROP_FAVOURITED:
-            priv->favourited = g_value_get_boolean(val);
+        case PROP_FOLLOWED:
+            priv->followed = g_value_get_boolean(val);
             break;
         case PROP_ONLINE:
             priv->online = g_value_get_boolean(val);
@@ -488,7 +488,7 @@ constructed(GObject* obj)
     priv->cache_filename = g_build_filename(g_get_user_cache_dir(), "gnome-twitch", "channels", id, NULL);
     g_free(id);
 
-    priv->favourited = gt_favourites_manager_is_channel_favourited(main_app->fav_mgr, self);
+    priv->followed = gt_follows_manager_is_channel_followed(main_app->fav_mgr, self);
 
     G_OBJECT_CLASS(gt_channel_parent_class)->constructed(obj);
 }
@@ -555,9 +555,9 @@ gt_channel_class_init(GtChannelClass* klass)
                                                            "Stream started time",
                                                            "Stream started time",
                                                            G_PARAM_READWRITE);
-    props[PROP_FAVOURITED] = g_param_spec_boolean("favourited",
-                                                  "Favourited",
-                                                  "Whether the channel is favourited",
+    props[PROP_FOLLOWED] = g_param_spec_boolean("followed",
+                                                  "Followed",
+                                                  "Whether the channel is followed",
                                                   FALSE,
                                                   G_PARAM_READWRITE);
     props[PROP_ONLINE] = g_param_spec_boolean("online",
@@ -597,10 +597,10 @@ gt_channel_init(GtChannel* self)
     priv->viewers = 0;
 
     g_signal_connect(self, "notify::auto-update", G_CALLBACK(auto_update_cb), NULL);
-    g_signal_connect(main_app->fav_mgr, "channel-favourited", G_CALLBACK(channel_favourited_cb), self);
-    g_signal_connect(main_app->fav_mgr, "channel-unfavourited", G_CALLBACK(channel_unfavourited_cb), self);
+    g_signal_connect(main_app->fav_mgr, "channel-followed", G_CALLBACK(channel_followed_cb), self);
+    g_signal_connect(main_app->fav_mgr, "channel-unfollowed", G_CALLBACK(channel_unfollowed_cb), self);
 
-    gt_favourites_manager_attach_to_channel(main_app->fav_mgr, self);
+    gt_follows_manager_attach_to_channel(main_app->fav_mgr, self);
 }
 
 static GParamSpec**
@@ -654,13 +654,11 @@ gt_channel_update_from_raw_data(GtChannel* self, GtChannelRawData* data)
 }
 
 void
-gt_channel_toggle_favourited(GtChannel* self)
+gt_channel_toggle_followed(GtChannel* self)
 {
     GtChannelPrivate* priv = gt_channel_get_instance_private(self);
 
-    priv->favourited = !priv->favourited;
-
-    g_object_notify_by_pspec(G_OBJECT(self), props[PROP_FAVOURITED]);
+    g_object_set(self, "followed", !priv->followed, NULL);
 }
 
 void
