@@ -1,8 +1,11 @@
 #include "gt-channels-container-game.h"
 #include "gt-twitch.h"
 #include "gt-app.h"
-#include "utils.h"
 #include <glib/gi18n.h>
+#include "utils.h"
+
+#define TAG "GtChannelsContainerGame"
+#include "gnome-twitch/gt-log.h"
 
 #define PCLASS GT_CHANNELS_CONTAINER_CLASS(gt_channels_container_game_parent_class)
 
