@@ -13,7 +13,7 @@ G_DECLARE_DERIVABLE_TYPE(GtChannelsContainer, gt_channels_container, GT, CHANNEL
 typedef enum
 {
     GT_CHANNELS_CONTAINER_TYPE_TOP,
-    GT_CHANNELS_CONTAINER_TYPE_FAVOURITE,
+    GT_CHANNELS_CONTAINER_TYPE_FOLLOW,
     GT_CHANNELS_CONTAINER_TYPE_SEARCH,
     GT_CHANNELS_CONTAINER_TYPE_GAME
 } GtChannelsContainerType;
