@@ -2,11 +2,17 @@
 #include "gt-irc.h"
 #include "gt-app.h"
 #include "gt-win.h"
-#include "utils.h"
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gprintf.h>
 #include <locale.h>
+#include <glib/gi18n.h>
+#include "utils.h"
+
+#define TAG "GtChat"
+#include "gnome-twitch/gt-log.h"
+
+//TODO: Replace copied text pixbufs with emoticon text
 
 #define CHAT_DARK_THEME_CSS_CLASS "dark-theme"
 #define CHAT_LIGHT_THEME_CSS_CLASS "light-theme"
@@ -21,8 +27,23 @@
 #define USER_MODE_TURBO 1 << 6
 #define USER_MODE_SUBSCRIBER 1 << 7
 
-const char* default_chat_colours[] = {"#FF0000", "#0000FF", "#00FF00", "#B22222", "#FF7F50", "#9ACD32", "#FF4500",
-                                      "#2E8B57", "#DAA520", "#D2691E", "#5F9EA0", "#1E90FF", "#FF69B4", "#8A2BE2", "#00FF7F"};
+#define MAX_SCROLLBACK 1000 //TODO: Make this a setting
+#define SAVEUP_AMOUNT 100
+
+const char* default_chat_colours[] =
+{
+    "#FF0000", "#0000FF", "#00FF00", "#B22222",
+    "#FF7F50", "#9ACD32", "#FF4500", "#2E8B57",
+    "#DAA520", "#D2691E", "#5F9EA0", "#1E90FF",
+    "#FF69B4", "#8A2BE2", "#00FF7F"
+};
+
+static gchar* emote_replacement_codes[] =
+{
+    NULL, ":-)", ":-(", ":-D", ">(",
+    ":-|", "o_O", "B-)", ":-O", "<3",
+    ":-/", ";-)", ":-P", ";-P", "R-)",
+};
 
 typedef struct
 {
@@ -32,14 +53,17 @@ typedef struct
 
     gboolean joined_channel;
 
+    GtkWidget* emote_popover;
+    GtkWidget* emote_flow;
+
     GtkWidget* error_label;
     GtkWidget* chat_view;
     GtkWidget* chat_scroll;
-    GtkAdjustment* chat_adjustment;
+    GtkWidget* chat_scroll_vbar;
     GtkWidget* chat_entry;
     GtkTextBuffer* chat_buffer;
+    GtkAdjustment* chat_adjustment;
     GtkTextTagTable* tag_table;
-    GHashTable* twitch_emotes;
     GtkWidget* main_stack;
     GtkWidget* connecting_revealer;
 
@@ -54,10 +78,11 @@ typedef struct
     GtIrc* chat;
     gchar* cur_chan;
 
-    gdouble prev_scroll_val;
-    gdouble prev_scroll_upper;
     gboolean chat_sticky;
-    gboolean force_sticky;
+
+    GRegex* url_regex;
+
+    GMutex mutex;
 } GtChatPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE(GtChat, gt_chat, GTK_TYPE_BOX)
@@ -105,6 +130,106 @@ send_msg_from_entry(GtChat* self)
     gtk_entry_set_text(GTK_ENTRY(priv->chat_entry), "");
 }
 
+static void
+emote_activated_cb(GtkFlowBox* box,
+                   GtkFlowBoxChild* child,
+                   gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+    GtkWidget* image = gtk_bin_get_child(GTK_BIN(child));
+    const gchar* code = g_object_get_data(G_OBJECT(image), "code");
+    const gchar* text = gtk_entry_get_text(GTK_ENTRY(priv->chat_entry));
+    gchar* new_text = NULL;
+
+    if (strlen(text) == 0 || text[strlen(text) - 1] == ' ')
+        new_text = g_strdup_printf("%s%s ", text, code);
+    else
+        new_text = g_strdup_printf("%s %s ", text, code);
+
+    gtk_entry_set_text(GTK_ENTRY(priv->chat_entry), new_text);
+
+    g_free(new_text);
+}
+
+static void
+emote_popup_closed_cb(GtkPopover* popover,
+                      gpointer udata)
+{
+    REMOVE_STYLE_CLASS(udata, "popup-open");
+}
+
+static void
+emote_icon_press_cb(GtkEntry* entry,
+                    GtkEntryIconPosition* pos,
+                    GdkEvent* evt,
+                    gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+    GdkRectangle rec;
+
+    gtk_entry_get_icon_area(entry, GTK_ENTRY_ICON_SECONDARY, &rec);
+    gtk_popover_set_pointing_to(GTK_POPOVER(priv->emote_popover), &rec);
+    gtk_widget_show(priv->emote_popover);
+    g_signal_connect(priv->emote_popover, "closed", G_CALLBACK(emote_popup_closed_cb), entry);
+
+    ADD_STYLE_CLASS(entry, "popup-open");
+}
+
+static gint
+int_compare(const GtEmote* a, const GtEmote* b)
+{
+    return a->id - b->id;
+}
+
+static void
+emoticons_cb(GObject* source,
+             GAsyncResult* res,
+             gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+    GError* error = NULL;
+    GList* emoticons = NULL;
+
+    emoticons = g_task_propagate_pointer(G_TASK(res), &error);
+
+    if (error)
+    {
+        //TODO: Show this error to user
+        WARNING("Couldn't get emoticons list");
+        return;
+    }
+
+    utils_container_clear(GTK_CONTAINER(priv->emote_flow));
+
+    emoticons = g_list_sort(emoticons, (GCompareFunc) int_compare);
+
+    for (GList* l = emoticons; l != NULL; l = l->next)
+    {
+        GtEmote* emote = l->data;
+        GtkWidget* image = gtk_image_new_from_pixbuf(emote->pixbuf);
+        gchar* code = NULL;;
+
+        gtk_widget_set_visible(image, TRUE);
+
+        if (emote->id < 15)
+            code = emote_replacement_codes[emote->id];
+        else
+            code = emote->code;
+
+        gtk_widget_set_tooltip_text(image, code);
+
+        g_object_set_data_full(G_OBJECT(image), "code",
+            g_strdup(code), g_free);
+
+        gtk_flow_box_insert(GTK_FLOW_BOX(priv->emote_flow), image, -1);
+    }
+
+    gt_emote_list_free(emoticons);
+}
+
 static gboolean
 irc_source_cb(GtIrcMessage* msg,
               gpointer udata)
@@ -112,17 +237,20 @@ irc_source_cb(GtIrcMessage* msg,
     GtChat* self = GT_CHAT(udata);
     GtChatPrivate* priv = gt_chat_get_instance_private(self);
     gboolean ret = G_SOURCE_REMOVE;
-    GtkTextIter iter;
 
-    gtk_text_buffer_get_end_iter(priv->chat_buffer, &iter);
+    g_mutex_lock(&priv->mutex);
 
     if (msg->cmd_type == GT_IRC_COMMAND_PRIVMSG)
     {
+        GtkTextIter iter;
         GtIrcCommandPrivmsg* privmsg = msg->cmd.privmsg;
         GtkTextTag* colour_tag;
         const gchar* sender;
 
-        if (!(sender = privmsg->display_name) || strlen(sender) < 1) sender = msg->nick;
+        gtk_text_buffer_get_end_iter(priv->chat_buffer, &iter);
+
+        if (!(sender = privmsg->display_name) || strlen(sender) < 1)
+            sender = msg->nick;
 
         if (!privmsg->colour || strlen(privmsg->colour) < 1)
             privmsg->colour = g_strdup(get_default_chat_colour(msg->nick));
@@ -158,6 +286,32 @@ irc_source_cb(GtIrcMessage* msg,
         gtk_text_buffer_insert_with_tags(priv->chat_buffer, &iter, sender, -1, colour_tag, NULL);
         gtk_text_buffer_insert(priv->chat_buffer, &iter, ": ", -1);
 
+        GMatchInfo* match_info = NULL;
+        glong match_offset_start = -1;
+        glong match_offset_end = -1;
+        GtkTextTag* url_tag = NULL;
+        gboolean done_matching = FALSE;
+
+#define UPDATE_URL_OFFSETS_AND_TAG()                                    \
+        if (!done_matching)                                             \
+        {                                                               \
+            gchar* match_string = g_match_info_fetch(match_info, 0);    \
+            gint match_start = -1;                                      \
+            gint match_end = -1;                                        \
+            g_match_info_fetch_pos(match_info, 0, &match_start, &match_end); \
+            match_offset_start = g_utf8_pointer_to_offset(privmsg->msg, privmsg->msg + match_start); \
+            match_offset_end = g_utf8_pointer_to_offset(privmsg->msg, privmsg->msg + match_end); \
+            done_matching = !g_match_info_next(match_info, NULL);       \
+            url_tag = gtk_text_buffer_create_tag(priv->chat_buffer, NULL, \
+                                                 "foreground", "blue",  \
+                                                 "underline", PANGO_UNDERLINE_SINGLE, \
+                                                 NULL);                 \
+            g_object_set_data(G_OBJECT(url_tag), "url", match_string);  \
+        }                                                               \
+
+        if (g_regex_match(priv->url_regex, privmsg->msg, 0, &match_info))
+            UPDATE_URL_OFFSETS_AND_TAG();
+
         gchar* c = g_utf8_offset_to_pointer(privmsg->msg, 0);
         gchar* d = g_utf8_offset_to_pointer(privmsg->msg, 1);
         GList* l = privmsg->emotes;
@@ -174,34 +328,45 @@ irc_source_cb(GtIrcMessage* msg,
                 l = l->next;
                 i = emote->end;
             }
+            else if (i >= match_offset_start && i < match_offset_end)
+            {
+                gtk_text_buffer_insert_with_tags(priv->chat_buffer, &iter, c, (d - c)*sizeof(gchar),
+                                                 url_tag, NULL);
+
+                if (i + 1 == match_offset_end)
+                    UPDATE_URL_OFFSETS_AND_TAG();
+            }
             else
                 gtk_text_buffer_insert(priv->chat_buffer, &iter, c, (d - c)*sizeof(gchar));
+
         }
 
+        g_match_info_free(match_info);
+
+#undef UPDATE_URL_OFFSETS
+
         gtk_text_buffer_insert(priv->chat_buffer, &iter, "\n", 1);
 
-        //TODO: Clean up
+        gtk_text_buffer_get_end_iter(priv->chat_buffer, &iter);
+
         gtk_text_buffer_move_mark(priv->chat_buffer, priv->bottom_mark, &iter);
 
-        gdouble cur_val = gtk_adjustment_get_value(priv->chat_adjustment);
-        gdouble cur_upper = gtk_adjustment_get_upper(priv->chat_adjustment);
-
-        // Scrolling upwards causes the pos to be further from the bottom than the natural size increment
-        if (priv->force_sticky || (priv->chat_sticky && cur_val > priv->prev_scroll_val - cur_upper + priv->prev_scroll_upper - 5))
-        {
+        if (priv->chat_sticky)
             gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(priv->chat_view), priv->bottom_mark);
-            priv->force_sticky = FALSE;
-        }
-        else
-            priv->chat_sticky = FALSE;
-
-        priv->prev_scroll_val = cur_val;
-        priv->prev_scroll_upper = cur_upper;
+    }
+    else if (msg->cmd_type == GT_IRC_COMMAND_USERSTATE)
+    {
+        const gchar* emote_sets = utils_search_key_value_strv(msg->tags, "emote-sets");
 
+        gt_twitch_emoticons_async(main_app->twitch, emote_sets,
+                                  (GAsyncReadyCallback) emoticons_cb,
+                                  NULL, self);
     }
 
     gt_irc_message_free(msg);
 
+    g_mutex_unlock(&priv->mutex);
+
     return G_SOURCE_CONTINUE;
 }
 
@@ -244,6 +409,76 @@ key_press_cb(GtkWidget* widget,
     return FALSE;
 }
 
+static gboolean
+chat_view_button_press_cb(GtkWidget* widget,
+                          GdkEventButton* evt,
+                          gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+    gint x, y;
+    GtkTextIter iter;
+    GSList* tags;
+
+    gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(priv->chat_view), GTK_TEXT_WINDOW_TEXT,
+                                          evt->x, evt->y, &x, &y);
+    gtk_text_view_get_iter_at_location(GTK_TEXT_VIEW(priv->chat_view), &iter, x, y);
+    tags = gtk_text_iter_get_tags(&iter);
+
+    for (GSList* l = tags; l != NULL; l = l->next)
+    {
+        gchar* url = g_object_get_data(G_OBJECT(l->data), "url");
+
+        if (url)
+            gtk_show_uri(gdk_screen_get_default(), url, GDK_CURRENT_TIME, NULL);
+    }
+
+    g_slist_free(tags);
+
+    return FALSE;
+}
+
+static gboolean
+chat_view_motion_cb(GtkWidget* widget,
+                    GdkEventMotion* evt,
+                    gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+    gint x, y;
+    GtkTextIter iter;
+    GSList* tags = NULL;
+    GdkCursor* cursor = NULL;
+
+    gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(widget),
+                                          GTK_TEXT_WINDOW_WIDGET,
+                                          evt->x, evt->y,
+                                          &x, &y);
+
+    gtk_text_view_get_iter_at_location(GTK_TEXT_VIEW(widget),
+        &iter, x, y);
+
+    tags = gtk_text_iter_get_tags(&iter);
+
+    for (GSList* l = tags; l != NULL; l = l->next)
+    {
+        if (g_object_get_data(G_OBJECT(l->data), "url"))
+        {
+            cursor = gdk_cursor_new_for_display(gdk_display_get_default(), GDK_HAND2);
+            break;
+        }
+    }
+
+    if (!cursor) cursor = gdk_cursor_new_for_display(gdk_display_get_default(), GDK_XTERM);
+
+    gdk_window_set_cursor(evt->window, cursor);
+
+    g_object_unref(cursor);
+
+
+    return GDK_EVENT_PROPAGATE;
+}
+
 static void
 reset_theme_css(GtChat* self)
 {
@@ -320,7 +555,7 @@ edge_reached_cb(GtkScrolledWindow* scroll,
     GtChatPrivate* priv = gt_chat_get_instance_private(self);
 
     if (pos == GTK_POS_BOTTOM)
-        priv->force_sticky = priv->chat_sticky = TRUE;
+        priv->chat_sticky = TRUE;
 }
 
 static void
@@ -333,8 +568,6 @@ anchored_cb(GtkWidget* widget,
     GtWin* win = GT_WIN_TOPLEVEL(self);
 
     g_signal_connect(main_app, "notify::oauth-token", G_CALLBACK(credentials_set_cb), self);
-
-    g_signal_handlers_disconnect_by_func(self, anchored_cb, udata); //One-shot
 }
 
 static void
@@ -371,9 +604,30 @@ after_connected_cb(GObject* source,
     GtChat* self = GT_CHAT(udata);
     GtChatPrivate* priv = gt_chat_get_instance_private(self);
 
-
     gtk_widget_set_sensitive(priv->chat_entry,
                              gt_app_credentials_valid(main_app));
+    gtk_entry_set_placeholder_text(GTK_ENTRY(priv->chat_entry),
+                                   gt_app_credentials_valid(main_app)
+                                   ? _("Send a message") : _("Please login to chat"));
+}
+
+static gboolean
+chat_scrolled_cb(GtkWidget* widget,
+                 GdkEvent* evt,
+                 gpointer udata)
+{
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+
+    if (widget == priv->chat_scroll && evt->type == GDK_SCROLL)
+    {
+        if (((GdkEventScroll*) evt)->delta_y < 0.0)
+            priv->chat_sticky = FALSE;
+    }
+    else if (widget == priv->chat_scroll_vbar && evt->type == GDK_BUTTON_PRESS)
+        priv->chat_sticky = FALSE;
+
+    return GDK_EVENT_PROPAGATE;
 }
 
 static void
@@ -383,6 +637,8 @@ finalise(GObject* obj)
     GtChatPrivate* priv = gt_chat_get_instance_private(self);
 
     G_OBJECT_CLASS(gt_chat_parent_class)->finalize(obj);
+
+    g_object_unref(priv->chat);
 }
 
 static void
@@ -442,7 +698,7 @@ gt_chat_class_init(GtChatClass* klass)
     obj_class->set_property = set_property;
 
     gtk_widget_class_set_template_from_resource(widget_class,
-                                                "/com/gnome-twitch/ui/gt-chat.ui");
+                                                "/com/vinszent/GnomeTwitch/ui/gt-chat.ui");
 
     gtk_widget_class_bind_template_child_private(widget_class, GtChat, chat_view);
     gtk_widget_class_bind_template_child_private(widget_class, GtChat, chat_scroll);
@@ -450,6 +706,8 @@ gt_chat_class_init(GtChatClass* klass)
     gtk_widget_class_bind_template_child_private(widget_class, GtChat, main_stack);
     gtk_widget_class_bind_template_child_private(widget_class, GtChat, error_label);
     gtk_widget_class_bind_template_child_private(widget_class, GtChat, connecting_revealer);
+    gtk_widget_class_bind_template_child_private(widget_class, GtChat, emote_popover);
+    gtk_widget_class_bind_template_child_private(widget_class, GtChat, emote_flow);
     gtk_widget_class_bind_template_callback(widget_class, reconnect_cb);
 
     props[PROP_DARK_THEME] = g_param_spec_boolean("dark-theme",
@@ -468,9 +726,33 @@ gt_chat_class_init(GtChatClass* klass)
 }
 
 static void
-scrolled()
+value_changed(GtkAdjustment* adjustment,
+              gpointer udata)
 {
-    g_print("Scrolled\n");
+    GtChat* self = GT_CHAT(udata);
+    GtChatPrivate* priv = gt_chat_get_instance_private(self);
+
+    gdouble val = gtk_adjustment_get_value(adjustment);
+    gdouble upper = gtk_adjustment_get_upper(adjustment);
+    gdouble page_size = gtk_adjustment_get_page_size(adjustment);
+
+    if (val >= upper - page_size - 5 || val < 1)
+    {
+        gint lc = gtk_text_buffer_get_line_count(priv->chat_buffer);
+
+        if (lc - MAX_SCROLLBACK >= SAVEUP_AMOUNT)
+        {
+            g_mutex_lock(&priv->mutex);
+
+            GtkTextIter start, end;
+
+            gtk_text_buffer_get_iter_at_line(priv->chat_buffer, &start, 0);
+            gtk_text_buffer_get_iter_at_line(priv->chat_buffer, &end, lc - MAX_SCROLLBACK);
+            gtk_text_buffer_delete(priv->chat_buffer, &start, &end);
+
+            g_mutex_unlock(&priv->mutex);
+        }
+    }
 }
 
 static void
@@ -480,34 +762,42 @@ gt_chat_init(GtChat* self)
 
     gtk_widget_init_template(GTK_WIDGET(self));
 
-    priv->chat_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(priv->chat_scroll));
+    g_mutex_init(&priv->mutex);
 
     priv->chat_css_provider = gtk_css_provider_new();
     gtk_style_context_add_provider(gtk_widget_get_style_context(GTK_WIDGET(self)),
                                    GTK_STYLE_PROVIDER(priv->chat_css_provider),
                                    GTK_STYLE_PROVIDER_PRIORITY_USER);
 
+    priv->chat_scroll_vbar = gtk_scrolled_window_get_vscrollbar(GTK_SCROLLED_WINDOW(priv->chat_scroll));
     priv->chat_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(priv->chat_view));
     priv->tag_table = gtk_text_buffer_get_tag_table(priv->chat_buffer);
-    priv->twitch_emotes = g_hash_table_new(g_direct_hash, g_direct_equal);
     gtk_text_buffer_get_end_iter(priv->chat_buffer, &priv->bottom_iter);
     priv->bottom_mark = gtk_text_buffer_create_mark(priv->chat_buffer, "end", &priv->bottom_iter, TRUE);
+    priv->chat_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(priv->chat_scroll));
 
     priv->chat = gt_irc_new();
     priv->cur_chan = NULL;
 
     priv->joined_channel = FALSE;
     priv->chat_sticky = TRUE;
-    priv->prev_scroll_val = 0;
-    priv->prev_scroll_upper = 0;
+
+    priv->url_regex = g_regex_new("(https?://([-\\w\\.]+)+(:\\d+)?(/([\\w/_\\.]*(\\?\\S+)?)?)?)",
+                                  G_REGEX_OPTIMIZE, 0, NULL);
 
     g_signal_connect(priv->chat_entry, "key-press-event", G_CALLBACK(key_press_cb), self);
-    g_signal_connect(self, "hierarchy-changed", G_CALLBACK(anchored_cb), self);
+    utils_signal_connect_oneshot(self, "hierarchy-changed", G_CALLBACK(anchored_cb), self);
     g_signal_connect(priv->chat, "error-encountered", G_CALLBACK(error_encountered_cb), self);
     g_signal_connect(priv->chat, "notify::logged-in", G_CALLBACK(connected_cb), self);
     g_signal_connect_after(priv->chat, "notify::logged-in", G_CALLBACK(after_connected_cb), self);
     g_signal_connect(priv->chat_scroll, "edge-reached", G_CALLBACK(edge_reached_cb), self);
-    g_signal_connect(priv->chat_scroll, "scroll-child", G_CALLBACK(scrolled), NULL);
+    g_signal_connect(priv->chat_view, "button-press-event", G_CALLBACK(chat_view_button_press_cb), self);
+    g_signal_connect(priv->chat_view, "motion-notify-event", G_CALLBACK(chat_view_motion_cb), self);
+    g_signal_connect(priv->chat_scroll, "scroll-event", G_CALLBACK(chat_scrolled_cb), self);
+    g_signal_connect(priv->chat_scroll_vbar, "button-press-event", G_CALLBACK(chat_scrolled_cb), self);
+    g_signal_connect(priv->chat_adjustment, "value-changed", G_CALLBACK(value_changed), self);
+    g_signal_connect(priv->chat_entry, "icon-press", G_CALLBACK(emote_icon_press_cb), self);
+    g_signal_connect(priv->emote_flow, "child-activated", G_CALLBACK(emote_activated_cb), self);
 
     g_object_bind_property(priv->chat, "logged-in",
                            priv->connecting_revealer, "reveal-child",
@@ -526,9 +816,11 @@ gt_chat_connect(GtChat* self, const gchar* chan)
 {
     GtChatPrivate* priv = gt_chat_get_instance_private(self);
 
+    if (gt_irc_is_connected(priv->chat)
+        && STRING_EQUALS(chan, priv->cur_chan)) return;
+
     priv->joined_channel = TRUE;
     priv->chat_sticky = TRUE;
-    priv->force_sticky = TRUE;
 
     g_clear_pointer(&priv->cur_chan, (GDestroyNotify) g_free);
     priv->cur_chan = g_strdup(chan);
@@ -538,7 +830,7 @@ gt_chat_connect(GtChat* self, const gchar* chan)
     g_clear_object(&priv->chat_badges_cancel);
     priv->chat_badges_cancel = g_cancellable_new();
 
-    gt_chat_badges_async(main_app->twitch, chan,
+    gt_twitch_chat_badges_async(main_app->twitch, chan,
                                 priv->chat_badges_cancel,
                                 (GAsyncReadyCallback) chat_badges_cb, self);
 }
