@@ -1,8 +1,11 @@
 #include "gt-games-container-top.h"
 #include "gt-app.h"
 #include "gt-twitch.h"
-#include "utils.h"
 #include <glib/gi18n.h>
+#include "utils.h"
+
+#define TAG "GtGamesContainerTop"
+#include "gnome-twitch/gt-log.h"
 
 #define PCLASS GT_GAMES_CONTAINER_CLASS(gt_games_container_top_parent_class)
 
