@@ -7,7 +7,7 @@ G_BEGIN_DECLS
 
 #define GT_TYPE_GAMES_CONTAINER (gt_games_container_get_type())
 
-G_DECLARE_DERIVABLE_TYPE(GtGamesContainer, gt_games_container, GT, GAMES_CONTAINER, GtkBox)
+G_DECLARE_DERIVABLE_TYPE(GtGamesContainer, gt_games_container, GT, GAMES_CONTAINER, GtkStack)
 
 typedef enum
 {
@@ -17,8 +17,11 @@ typedef enum
 
 struct _GtGamesContainerClass
 {
-    GtkBoxClass parent_class;
+    GtkStackClass parent_class;
 
+    void (*check_empty) (GtGamesContainer* self);
+    void (*set_empty_info) (GtGamesContainer* self, const gchar* icon_name, const gchar* title, const gchar* subtitle);
+    void (*set_loading_info) (GtGamesContainer* self, const gchar* title);
     void (*show_load_spinner) (GtGamesContainer* self, gboolean show);
     void (*append_games) (GtGamesContainer* self, GList* games);
     GtkFlowBox* (*get_games_flow) (GtGamesContainer* self);
