@@ -509,7 +509,7 @@ handle_message(GtIrc* self, GOutputStream* ostream, GtIrcMessage* msg)
 
                 g_error_free(err);
 
-                WARNINGF("Unable to log in on recive socket, server replied with message='%s'",
+                WARNINGF("Unable to log in on receive socket, server replied with message='%s'",
                           msg->cmd.notice->msg);
 
                 return FALSE;
@@ -720,7 +720,7 @@ gt_irc_connect(GtIrc* self,
         g_print("Error\n");
         goto cleanup;
     }
-    g_clear_error(&err); // Probably unecessary
+    g_clear_error(&err); // Probably unnecessary
     priv->irc_conn_send = g_socket_client_connect(sock_client, addr, NULL, &err);
     if (err)
     {
