@@ -8,15 +8,11 @@ G_BEGIN_DECLS
 
 #define GT_TYPE_PLAYER (gt_player_get_type())
 
-G_DECLARE_DERIVABLE_TYPE(GtPlayer, gt_player, GT, PLAYER, GtkBin)
+G_DECLARE_FINAL_TYPE(GtPlayer, gt_player, GT, PLAYER, GtkBin)
 
-struct _GtPlayerClass
+struct _GtPlayer
 {
-    GtkBinClass parent_class;
-
-    void (*set_uri) (GtPlayer* self, const gchar* uri);
-    void (*play) (GtPlayer* self);
-    void (*stop) (GtPlayer* self);
+    GtkBin parent_instance;
 };
 
 void gt_player_open_channel(GtPlayer* self, GtChannel* chan);
