@@ -9,7 +9,13 @@ G_BEGIN_DECLS
 
 #define GT_TYPE_SETTINGS_DLG (gt_settings_dlg_get_type())
 
-G_DECLARE_FINAL_TYPE(GtSettingsDlg, gt_settings_dlg, GT, SETTINGS_DLG, GtkDialog)
+G_DECLARE_FINAL_TYPE(GtSettingsDlg, gt_settings_dlg, GT, SETTINGS_DLG, GtkDialog);
+
+typedef enum _GtSettingsDlgView
+{
+    GT_SETTINGS_DLG_VIEW_GENERAL,
+    GT_SETTINGS_DLG_VIEW_PLUGINS
+} GtSettingsDlgView;
 
 struct _GtSettingsDlg
 {
@@ -17,6 +23,7 @@ struct _GtSettingsDlg
 };
 
 GtSettingsDlg* gt_settings_dlg_new(GtWin* win);
+void gt_settings_dlg_set_view(GtSettingsDlg* self, GtSettingsDlgView view);
 
 G_END_DECLS
 
