@@ -1,7 +1,16 @@
 #include "gt-twitch-login-dlg.h"
-#include <webkit2/webkit2.h>
+#include "config.h"
 #include <glib/gi18n.h>
 
+#define TAG "GtTwitchLoginDlg"
+#include "gnome-twitch/gt-log.h"
+
+#ifdef USE_DEPRECATED_WEBKIT
+#include <webkit/webkit.h>
+#else
+#include <webkit2/webkit2.h>
+#endif
+
 typedef struct
 {
     GtkWidget* web_view;
@@ -82,20 +91,20 @@ gt_twitch_login_dlg_class_init(GtTwitchLoginDlgClass* klass)
     obj_class->set_property = set_property;
 
     gtk_widget_class_set_template_from_resource(widget_class,
-                                                "/com/gnome-twitch/ui/gt-twitch-login-dlg.ui");
+                                                "/com/vinszent/GnomeTwitch/ui/gt-twitch-login-dlg.ui");
 
     gtk_widget_class_bind_template_child_private(widget_class, GtTwitchLoginDlg, web_view);
 }
 
 static void
-user_name_cb(GObject* source,
+oauth_info_cb(GObject* source,
              GAsyncResult* res,
              gpointer udata)
 {
     GtTwitchLoginDlg* self = GT_TWITCH_LOGIN_DLG(udata);
     GError* error = NULL;
 
-    gchar* user_name = g_task_propagate_pointer(G_TASK(res), &error);
+    GtTwitchOAuthInfo* oauth_info = g_task_propagate_pointer(G_TASK(res), &error);
 
     if (error)
     {
@@ -104,50 +113,74 @@ user_name_cb(GObject* source,
         return; //TODO: Show error to user
     }
 
-    g_message("{GtTwitchLoginDlg} Successfulyy got username=%s", user_name);
+    MESSAGEF("Successfully got username '%s'", oauth_info->user_name);
 
-    g_object_set(main_app, "user-name", user_name, NULL);
+    g_object_set(main_app, "user-name", oauth_info->user_name, NULL);
 
     gt_win_show_info_message(GT_WIN(gtk_window_get_transient_for(GTK_WINDOW(self))),
                              _("Successfully logged in to Twitch!"));
 
-    g_free(user_name);
+    g_free(oauth_info);
     gtk_widget_destroy(GTK_WIDGET(self));
 }
 
-static void
-uri_changed_cb(GObject* source,
-               GParamSpec* pspec,
-               gpointer udata)
+static gboolean
+#ifdef USE_DEPRECATED_WEBKIT
+redirect_cb(WebKitWebView* web_view,
+            WebKitWebFrame* web_frame,
+            WebKitNetworkRequest* request,
+            WebKitWebNavigationAction* action,
+            WebKitWebPolicyDecision* decision,
+            gpointer udata)
+#else
+redirect_cb(WebKitWebView* web_view,
+            WebKitPolicyDecision* decision,
+            WebKitPolicyDecisionType type,
+            gpointer udata)
+#endif
 {
     GtTwitchLoginDlg* self = GT_TWITCH_LOGIN_DLG(udata);
     GtTwitchLoginDlgPrivate* priv = gt_twitch_login_dlg_get_instance_private(self);
-    gchar* url;
     GMatchInfo* match_info = NULL;
+    const gchar* uri = NULL;
 
-    g_object_get(source, "uri", &url, NULL);
+#ifdef USE_DEPRECATED_WEBKIT
+    uri = webkit_network_request_get_uri(request);
+#else
+    if (type == WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION)
+    {
+        WebKitNavigationAction* action = webkit_navigation_policy_decision_get_navigation_action(
+            WEBKIT_NAVIGATION_POLICY_DECISION(decision));
+        WebKitURIRequest* request = webkit_navigation_action_get_request(action);
 
-    g_info("{GtTwitchLoginDlg} Redirect url is '%s'", url);
+        uri = webkit_uri_request_get_uri(request);
+    }
+#endif
 
-    g_regex_match(priv->token_redirect_regex, url, 0, &match_info);
+    if (uri == NULL || strlen(uri) == 0) return FALSE;
+
+    INFOF("Redirect uri is '%s'", uri);
+
+    g_regex_match(priv->token_redirect_regex, uri, 0, &match_info);
     if (g_match_info_matches(match_info))
     {
         gchar* token = g_match_info_fetch(match_info, 1);
 
         g_object_set(main_app, "oauth-token", token, NULL);
 
-        g_message("{GtTwitchLoginDlg} Successfully got OAuth token '%s'", token);
+        MESSAGEF("Successfully got OAuth token '%s'", token);
 
-        gt_twitch_user_name_async(main_app->twitch, user_name_cb, self);
+        gt_twitch_oauth_info_async(main_app->twitch, oauth_info_cb, self);
 
         g_free(token);
 
     }
-    else if (g_str_has_prefix(url, "http://localhost/?error=access_denied"))
-        g_message("{GtTwitchLoginDlg} Error logging or login cancelled");
+    else if (g_str_has_prefix(uri, "http://localhost/?error=access_denied"))
+        WARNING("Error logging in or login cancelled");
 
     g_match_info_unref(match_info);
-    g_free(url);
+
+    return FALSE;
 }
 
 static void
@@ -159,7 +192,11 @@ gt_twitch_login_dlg_init(GtTwitchLoginDlg* self)
 
     gtk_widget_init_template(GTK_WIDGET(self));
 
-    g_signal_connect(priv->web_view, "notify::uri", G_CALLBACK(uri_changed_cb), self);
+#ifdef USE_DEPRECATED_WEBKIT
+    g_signal_connect(priv->web_view, "navigation-policy-decision-requested", G_CALLBACK(redirect_cb), self);
+#else
+    g_signal_connect(priv->web_view, "decide-policy", G_CALLBACK(redirect_cb), self);
+#endif
 
     const gchar* uri = g_strdup_printf("https://api.twitch.tv/kraken/oauth2/authorize?response_type=token&client_id=%s&redirect_uri=%s&scope=%s", "afjnp6n4ufzott4atb3xpb8l5a31aav", "http://localhost", "chat_login+user_follows_edit");
 
