@@ -186,8 +186,6 @@ send_message(GtTwitch* self, SoupMessage* msg)
 
     soup_message_headers_append(msg->request_headers, "Client-ID", CLIENT_ID);
 
-    soup_message_headers_append(msg->request_headers, "Client-ID", CLIENT_ID);
-
     soup_session_send_message(priv->soup, msg);
 
     ret = SOUP_STATUS_IS_SUCCESSFUL(msg->status_code);
@@ -1082,7 +1080,7 @@ channel_raw_data_cb(GTask* task,
     g_task_return_pointer(task, ret, (GDestroyNotify) gt_twitch_channel_raw_data_free);
 }
 
-// This was a bit unecessary, but at least it's here if it's ever needed
+// This was a bit unnecessary, but at least it's here if it's ever needed
 G_DEPRECATED
 void
 gt_twitch_channel_raw_data_async(GtTwitch* self, const gchar* name,
@@ -1720,7 +1718,7 @@ gt_twitch_follows_all(GtTwitch* self, const gchar* user_name, GError** error)
             _("Twitch replied with error code '%d', message '%s' and body '%s'"),
             msg->status_code, msg->reason_phrase, msg->response_body->data);
 
-        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOWS_ALL, msg_str);
+        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOWS_ALL, "%s", msg_str);
 
         g_free(msg_str);
 
@@ -1864,7 +1862,7 @@ gt_twitch_follow_channel(GtTwitch* self,
             _("Twitch replied with error code '%d', message '%s' and body '%s'"),
             msg->status_code, msg->reason_phrase, msg->response_body->data);
 
-        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOW_CHANNEL, msg_str);
+        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOW_CHANNEL, "%s", msg_str);
 
         g_free(msg_str);
 
@@ -1942,7 +1940,7 @@ gt_twitch_unfollow_channel(GtTwitch* self,
             _("Twitch replied with error code '%d', message '%s' and body '%s'"),
             msg->status_code, msg->reason_phrase, msg->response_body->data);
 
-        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOW_CHANNEL, msg_str);
+        g_set_error(error, GT_TWITCH_ERROR, GT_TWITCH_ERROR_FOLLOW_CHANNEL, "%s", msg_str);
 
         g_free(msg_str);
 
