@@ -6,8 +6,9 @@
 #include "gt-channel.h"
 #include "gt-games-view.h"
 #include "gt-channels-view.h"
+#include "gt-player.h"
 
-#define GT_WIN_TOPLEVEL(w) GT_WIN(gtk_widget_get_toplevel(GTK_WIDGET(w)))
+#define GT_WIN_TOPLEVEL(w) GT_WIN(gtk_widget_get_ancestor(GTK_WIDGET(w), GTK_TYPE_WINDOW))
 #define GT_WIN_ACTIVE GT_WIN(gtk_application_get_active_window(GTK_APPLICATION(main_app)))
 
 G_BEGIN_DECLS
@@ -20,8 +21,7 @@ struct _GtWin
 {
     GtkApplicationWindow parent_instance;
 
-    GtkWidget* player;
-    //   GtChannel* open_channel;
+    GtPlayer* player;
 };
 
 GtWin* gt_win_new(GtApp* app);
@@ -32,11 +32,13 @@ void gt_win_browse_games_view(GtWin* self);
 void gt_win_start_search(GtWin* self);
 void gt_win_stop_search(GtWin* self);
 void gt_win_refresh_view(GtWin* self);
-void gt_win_show_favourites(GtWin* self);
+void gt_win_show_follows(GtWin* self);
 GtGamesView* gt_win_get_games_view(GtWin* self);
 GtChannelsView* gt_win_get_channels_view(GtWin* self);
-gboolean gt_win_get_fullscreen(GtWin* self);
+gboolean gt_win_is_fullscreen(GtWin* self);
+void gt_win_toggle_fullscreen(GtWin* self);
 void gt_win_show_info_message(GtWin* self, const gchar* msg);
+void gt_win_show_error_message(GtWin* self, const gchar* secondary, const gchar* details);
 void gt_win_ask_question(GtWin* self, const gchar* msg, GCallback cb, gpointer udata);
 
 G_END_DECLS
