@@ -7,6 +7,8 @@
 #define REMOVE_STYLE_CLASS(w, n) gtk_style_context_remove_class(gtk_widget_get_style_context(GTK_WIDGET(w)), n)
 #define ADD_STYLE_CLASS(w, n) gtk_style_context_add_class(gtk_widget_get_style_context(GTK_WIDGET(w)), n)
 #define UROUND(x) ((guint) ((x) + 0.5))
+#define PRINT_BOOL(b) b ? "true" : "false"
+#define STRING_EQUALS(a, b) g_strcmp0(a, b) == 0
 
 gpointer utils_value_ref_sink_object(const GValue* val);
 gchar* utils_value_dup_string_allow_null(const GValue* val);
@@ -20,5 +22,6 @@ const gchar* utils_search_key_value_strv(gchar** strv, const gchar* key);
 void utils_connect_mouse_hover(GtkWidget* widget);
 void utils_connect_link(GtkWidget* widget, const gchar* link);
 gboolean utils_str_empty(const gchar* str);
+void utils_signal_connect_oneshot(gpointer instance, const gchar* signal, GCallback cb, gpointer udata);
 
 #endif
